@@ -105,7 +105,14 @@ def rm_server_redis(clean=False):
     pass
 
 
-def server_mongo(card='lo',user='webuser'):
+def server_nscd():
+    yum_install('nscd')
+    run('chkconfig --level 35 nscd on')
+    run('service nscd start')
+    pass
+
+
+def server_mongo(card='lo', user='webuser'):
     """
     @note this mongo only support 64-bit system
     :return:
@@ -135,6 +142,7 @@ def server_mongo(card='lo',user='webuser'):
     io_slowlog('mongo', 'mongod')
     with settings(warn_only=True):
         run('mkdir -p /storage/mongo')
+        run('chown -Rf mongod.mongod /storage/mongo')
 
     pass
 
@@ -172,7 +180,7 @@ def server_supervisor(user='webuser', tmp='/tmp', log_dir='/logs/supervisor', lo
     # pass
     #
     # with tempfile.NamedTemporaryFile('w', delete=False) as fh:
-    #     print>> fh, buf
+    # print>> fh, buf
     #
     # put(fh.name, '/etc/init.d/supervisord')
     # os.remove(fh.name)
@@ -250,7 +258,6 @@ def server_websuite(user='webuser', python_version='3.4.2', only_pypy=True, pypy
 
 
 def server_mysql():
-
     cmd_ulimit()
 
     with settings(warn_only=True):
@@ -280,8 +287,6 @@ def server_tengine(user='webuser', version=None, tornado=True, process=1, connec
     :return:
     """
 
-
-
     utils_baselib()
     run('yum install jemalloc jemalloc-devel  -y')
     run('yum install GeoIP GeoIP-devel GeoIP-update GeoIP-update6 -y')
@@ -320,7 +325,7 @@ def server_tengine(user='webuser', version=None, tornado=True, process=1, connec
                     # dir path
                     '--pid-path=/usr/local/var/run/nginx.pid --lock-path=/usr/local/var/lock/nginx '
 
-                    #file path
+                    # file path
                     ' --http-client-body-temp-path=/aircache/nginx/body_temp'
                     ' --http-proxy-temp-path=/aircache/nginx/proxy_temp'
                     ' --error-log-path=/logs/nginx/error.log --http-log-path=/logs/nginx/access.log'
@@ -368,7 +373,7 @@ def server_tengine(user='webuser', version=None, tornado=True, process=1, connec
                     # dir path
                     '--pid-path=/usr/local/var/run/nginx.pid --lock-path=/usr/local/var/lock/nginx '
 
-                    #file path
+                    # file path
                     ' --http-client-body-temp-path=/aircache/nginx/body_temp'
                     ' --http-proxy-temp-path=/aircache/nginx/proxy_temp'
                     ' --error-log-path=/logs/nginx/error.log --http-log-path=/logs/nginx/access.log'
@@ -404,7 +409,6 @@ def server_tengine(user='webuser', version=None, tornado=True, process=1, connec
 
                     ' --with-http_footer_filter_module=shared'.format(user))
 
-
             run('make')
 
             with settings(warn_only=True):
@@ -469,15 +473,11 @@ def server_tengine(user='webuser', version=None, tornado=True, process=1, connec
     pass
 
 
-
-
-
 def server_monit(version='5.5-1'):
-
     # 5.5.1-41
     # run('yum install monit -y')
     # with settings(warn_only=True):
-    #     run('for i in `rpm -ql monit`;do rm -rf $i; done;')
+    # run('for i in `rpm -ql monit`;do rm -rf $i; done;')
     #     run('rpm -e `rpm -qa | grep -i monit`')
 
     with settings(warn_only=True):
@@ -487,8 +487,6 @@ def server_monit(version='5.5-1'):
     pass
 
 
-
-
 def server_phpd(user='webuser'):
     """
     install php
@@ -502,7 +500,7 @@ def server_phpd(user='webuser'):
     io_webdata(uid=user, gid=user)
     io_slowlog('nginx', user)
     io_slowlog('php-fpm', user)
-    server_tengine(user=user,tornado=False)
+    server_tengine(user=user, tornado=False)
 
     yum_install('php', newer='remi')
     yum_install('php-fpm', newer='remi')
@@ -512,14 +510,35 @@ def server_phpd(user='webuser'):
     yum_install('php-pecl-mongo', newer='remi')
     yum_install('php-pecl-zendopcache', newer='remi')
 
-
     run('chkconfig --level 35 php-fpm on')
     pass
 
 
+def server_nodejs(user='webuser'):
+    utils_baselib()
+    utils_remi()
+    cmd_useradd(user)
+    yum_install('nodejs', newer='remi')
+    pass
+
+
+def server_statsd(root, repo='https://github.com/nextoa/statsd.git', user='webuser', monit='5.5-1'):
+    if monit:
+        server_monit(monit)
+
+    server_nodejs(user)
+    io_slowlog('statsd', user)
+    cmd_git(root, repo, branch='master', user=user)
+
+    cmd_su('cp {}/exampleConfig.js {}/userconfig.js'.format(root))
+
+    node_path = run('which node')
+
+    pass
+
 
 # def server_smtp():
-#     utils_remi()
+# utils_remi()
 #     cmd_ulimit()
 #
 #     yum_install('sendmail', newer="remi")
@@ -537,7 +556,7 @@ def server_phpd(user='webuser'):
 #     pass
 
 
-def server_smtp(host,domain,networks):
+def server_smtp(host, domain, networks):
     # utils_remi()
     # cmd_ulimit()
 
@@ -549,14 +568,14 @@ def server_smtp(host,domain,networks):
     try:
         template = pkg_resources.resource_string('fabez', 'tpl/postfix.cf')
     except:
-        template = open(os.path.join(os.path.dirname(__file__), 'tpl','postfix.cf')).read()
+        template = open(os.path.join(os.path.dirname(__file__), 'tpl', 'postfix.cf')).read()
         pass
 
     buf = template.replace('{$myhostname}', host) \
         .replace('{$mydomain}', domain) \
         .replace('{$mynetworks}', networks) \
-
-
+ \
+ \
     # only support python2.x
     with tempfile.NamedTemporaryFile('w', delete=False) as fh:
         print>> fh, buf
@@ -569,11 +588,6 @@ def server_smtp(host,domain,networks):
     pass
 
 
-
-
-
-
-
 # restart feature
 def restart_web(config=None):
     # supervisor_restart()
